<?php

global $newuser_text;
$newuser_text = array (

'registernewuser'	=>	'Register new user',
'requiredfields'	=>	'Required fields are marked with a',
'username'			=>	'Username',
'password'			=>	'Password',
'confirmpass'		=>	'Confirm Password',
'realname'			=>	'Real Name',
'emailaddress'		=>	'Email Address',
'jabberid'			=>	'Jabber ID',
'notifications'		=>	'Notifications',
'none'				=>	'None',
'email'				=>	'Email',
'jabber'			=>	'Jabber',
//'group'				=>	'Group',  Not used from 0.9.7
'registeraccount'	=>	'Register this account',

// New in 0.9.7

'globalgroup'		=>	'Global group',

);
?>
